{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y '\N{U+0433}'. G",
    GyMMM => "LLL y '\N{U+0433}'. G",
    GyMMMEd => "E, d MMM y '\N{U+0433}'. G",
    GyMMMd => "d MMM y '\N{U+0433}'. G",
    GyMd => "dd.MM.y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-few" => "W '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' MMMM",
    "MMMMW-count-many" => "W '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' MMMM",
    "MMMMW-count-one" => "W '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' MMMM",
    "MMMMW-count-other" => "W '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d.M",
    d => "d",
    h => "hh a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm.ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "LLL y",
    yMMMEd => "E, d MMM y",
    yMMMM => "LLLL y",
    yMMMd => "d MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "w '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' Y",
    "yw-count-many" => "w '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' Y",
    "yw-count-one" => "w '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' Y",
    "yw-count-other" => "w '\N{U+0442}\N{U+044b}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}' Y",
  },
  code => "be-BY",
  date_format_full => "EEEE, d MMMM y '\N{U+0433}'.",
  date_format_long => "d MMMM y '\N{U+0433}'.",
  date_format_medium => "d MMM y '\N{U+0433}'.",
  date_format_short => "d.MM.yy",
  datetime_format_full => "{1} '\N{U+0443}' {0}",
  datetime_format_long => "{1} '\N{U+0443}' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+043f}\N{U+043d}",
    "\N{U+0430}\N{U+045e}",
    "\N{U+0441}\N{U+0440}",
    "\N{U+0447}\N{U+0446}",
    "\N{U+043f}\N{U+0442}",
    "\N{U+0441}\N{U+0431}",
    "\N{U+043d}\N{U+0434}",
  ],
  day_format_narrow => [
    "\N{U+043f}",
    "\N{U+0430}",
    "\N{U+0441}",
    "\N{U+0447}",
    "\N{U+043f}",
    "\N{U+0441}",
    "\N{U+043d}",
  ],
  day_format_wide => [
    "\N{U+043f}\N{U+0430}\N{U+043d}\N{U+044f}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+043a}",
    "\N{U+0430}\N{U+045e}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "\N{U+0441}\N{U+0435}\N{U+0440}\N{U+0430}\N{U+0434}\N{U+0430}",
    "\N{U+0447}\N{U+0430}\N{U+0446}\N{U+0432}\N{U+0435}\N{U+0440}",
    "\N{U+043f}\N{U+044f}\N{U+0442}\N{U+043d}\N{U+0456}\N{U+0446}\N{U+0430}",
    "\N{U+0441}\N{U+0443}\N{U+0431}\N{U+043e}\N{U+0442}\N{U+0430}",
    "\N{U+043d}\N{U+044f}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043b}\N{U+044f}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+043f}\N{U+043d}",
    "\N{U+0430}\N{U+045e}",
    "\N{U+0441}\N{U+0440}",
    "\N{U+0447}\N{U+0446}",
    "\N{U+043f}\N{U+0442}",
    "\N{U+0441}\N{U+0431}",
    "\N{U+043d}\N{U+0434}",
  ],
  day_stand_alone_narrow => [
    "\N{U+043f}",
    "\N{U+0430}",
    "\N{U+0441}",
    "\N{U+0447}",
    "\N{U+043f}",
    "\N{U+0441}",
    "\N{U+043d}",
  ],
  day_stand_alone_wide => [
    "\N{U+043f}\N{U+0430}\N{U+043d}\N{U+044f}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+043a}",
    "\N{U+0430}\N{U+045e}\N{U+0442}\N{U+043e}\N{U+0440}\N{U+0430}\N{U+043a}",
    "\N{U+0441}\N{U+0435}\N{U+0440}\N{U+0430}\N{U+0434}\N{U+0430}",
    "\N{U+0447}\N{U+0430}\N{U+0446}\N{U+0432}\N{U+0435}\N{U+0440}",
    "\N{U+043f}\N{U+044f}\N{U+0442}\N{U+043d}\N{U+0456}\N{U+0446}\N{U+0430}",
    "\N{U+0441}\N{U+0443}\N{U+0431}\N{U+043e}\N{U+0442}\N{U+0430}",
    "\N{U+043d}\N{U+044f}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043b}\N{U+044f}",
  ],
  era_abbreviated => [
    "\N{U+0434}\N{U+0430} \N{U+043d}.\N{U+044d}.",
    "\N{U+043d}.\N{U+044d}.",
  ],
  era_narrow => [
    "\N{U+0434}\N{U+0430} \N{U+043d}.\N{U+044d}.",
    "\N{U+043d}.\N{U+044d}.",
  ],
  era_wide => [
    "\N{U+0434}\N{U+0430} \N{U+043d}\N{U+0430}\N{U+0440}\N{U+0430}\N{U+0434}\N{U+0436}\N{U+044d}\N{U+043d}\N{U+043d}\N{U+044f} \N{U+0425}\N{U+0440}\N{U+044b}\N{U+0441}\N{U+0442}\N{U+043e}\N{U+0432}\N{U+0430}",
    "\N{U+0430}\N{U+0434} \N{U+043d}\N{U+0430}\N{U+0440}\N{U+0430}\N{U+0434}\N{U+0436}\N{U+044d}\N{U+043d}\N{U+043d}\N{U+044f} \N{U+0425}\N{U+0440}\N{U+044b}\N{U+0441}\N{U+0442}\N{U+043e}\N{U+0432}\N{U+0430}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Belarusian",
  month_format_abbreviated => [
    "\N{U+0441}\N{U+0442}\N{U+0443}",
    "\N{U+043b}\N{U+044e}\N{U+0442}",
    "\N{U+0441}\N{U+0430}\N{U+043a}",
    "\N{U+043a}\N{U+0440}\N{U+0430}",
    "\N{U+043c}\N{U+0430}\N{U+044f}",
    "\N{U+0447}\N{U+044d}\N{U+0440}",
    "\N{U+043b}\N{U+0456}\N{U+043f}",
    "\N{U+0436}\N{U+043d}\N{U+0456}",
    "\N{U+0432}\N{U+0435}\N{U+0440}",
    "\N{U+043a}\N{U+0430}\N{U+0441}",
    "\N{U+043b}\N{U+0456}\N{U+0441}",
    "\N{U+0441}\N{U+043d}\N{U+0435}",
  ],
  month_format_narrow => [
    "\N{U+0441}",
    "\N{U+043b}",
    "\N{U+0441}",
    "\N{U+043a}",
    "\N{U+043c}",
    "\N{U+0447}",
    "\N{U+043b}",
    "\N{U+0436}",
    "\N{U+0432}",
    "\N{U+043a}",
    "\N{U+043b}",
    "\N{U+0441}",
  ],
  month_format_wide => [
    "\N{U+0441}\N{U+0442}\N{U+0443}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044f}",
    "\N{U+043b}\N{U+044e}\N{U+0442}\N{U+0430}\N{U+0433}\N{U+0430}",
    "\N{U+0441}\N{U+0430}\N{U+043a}\N{U+0430}\N{U+0432}\N{U+0456}\N{U+043a}\N{U+0430}",
    "\N{U+043a}\N{U+0440}\N{U+0430}\N{U+0441}\N{U+0430}\N{U+0432}\N{U+0456}\N{U+043a}\N{U+0430}",
    "\N{U+043c}\N{U+0430}\N{U+044f}",
    "\N{U+0447}\N{U+044d}\N{U+0440}\N{U+0432}\N{U+0435}\N{U+043d}\N{U+044f}",
    "\N{U+043b}\N{U+0456}\N{U+043f}\N{U+0435}\N{U+043d}\N{U+044f}",
    "\N{U+0436}\N{U+043d}\N{U+0456}\N{U+045e}\N{U+043d}\N{U+044f}",
    "\N{U+0432}\N{U+0435}\N{U+0440}\N{U+0430}\N{U+0441}\N{U+043d}\N{U+044f}",
    "\N{U+043a}\N{U+0430}\N{U+0441}\N{U+0442}\N{U+0440}\N{U+044b}\N{U+0447}\N{U+043d}\N{U+0456}\N{U+043a}\N{U+0430}",
    "\N{U+043b}\N{U+0456}\N{U+0441}\N{U+0442}\N{U+0430}\N{U+043f}\N{U+0430}\N{U+0434}\N{U+0430}",
    "\N{U+0441}\N{U+043d}\N{U+0435}\N{U+0436}\N{U+043d}\N{U+044f}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0441}\N{U+0442}\N{U+0443}",
    "\N{U+043b}\N{U+044e}\N{U+0442}",
    "\N{U+0441}\N{U+0430}\N{U+043a}",
    "\N{U+043a}\N{U+0440}\N{U+0430}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0447}\N{U+044d}\N{U+0440}",
    "\N{U+043b}\N{U+0456}\N{U+043f}",
    "\N{U+0436}\N{U+043d}\N{U+0456}",
    "\N{U+0432}\N{U+0435}\N{U+0440}",
    "\N{U+043a}\N{U+0430}\N{U+0441}",
    "\N{U+043b}\N{U+0456}\N{U+0441}",
    "\N{U+0441}\N{U+043d}\N{U+0435}",
  ],
  month_stand_alone_narrow => [
    "\N{U+0441}",
    "\N{U+043b}",
    "\N{U+0441}",
    "\N{U+043a}",
    "\N{U+043c}",
    "\N{U+0447}",
    "\N{U+043b}",
    "\N{U+0436}",
    "\N{U+0432}",
    "\N{U+043a}",
    "\N{U+043b}",
    "\N{U+0441}",
  ],
  month_stand_alone_wide => [
    "\N{U+0441}\N{U+0442}\N{U+0443}\N{U+0434}\N{U+0437}\N{U+0435}\N{U+043d}\N{U+044c}",
    "\N{U+043b}\N{U+044e}\N{U+0442}\N{U+044b}",
    "\N{U+0441}\N{U+0430}\N{U+043a}\N{U+0430}\N{U+0432}\N{U+0456}\N{U+043a}",
    "\N{U+043a}\N{U+0440}\N{U+0430}\N{U+0441}\N{U+0430}\N{U+0432}\N{U+0456}\N{U+043a}",
    "\N{U+043c}\N{U+0430}\N{U+0439}",
    "\N{U+0447}\N{U+044d}\N{U+0440}\N{U+0432}\N{U+0435}\N{U+043d}\N{U+044c}",
    "\N{U+043b}\N{U+0456}\N{U+043f}\N{U+0435}\N{U+043d}\N{U+044c}",
    "\N{U+0436}\N{U+043d}\N{U+0456}\N{U+0432}\N{U+0435}\N{U+043d}\N{U+044c}",
    "\N{U+0432}\N{U+0435}\N{U+0440}\N{U+0430}\N{U+0441}\N{U+0435}\N{U+043d}\N{U+044c}",
    "\N{U+043a}\N{U+0430}\N{U+0441}\N{U+0442}\N{U+0440}\N{U+044b}\N{U+0447}\N{U+043d}\N{U+0456}\N{U+043a}",
    "\N{U+043b}\N{U+0456}\N{U+0441}\N{U+0442}\N{U+0430}\N{U+043f}\N{U+0430}\N{U+0434}",
    "\N{U+0441}\N{U+043d}\N{U+0435}\N{U+0436}\N{U+0430}\N{U+043d}\N{U+044c}",
  ],
  name => "Belarusian Belarus",
  native_language => "\N{U+0431}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+0440}\N{U+0443}\N{U+0441}\N{U+043a}\N{U+0430}\N{U+044f}",
  native_name => "\N{U+0431}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+0440}\N{U+0443}\N{U+0441}\N{U+043a}\N{U+0430}\N{U+044f} \N{U+0411}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+0440}\N{U+0443}\N{U+0441}\N{U+044c}",
  native_script => undef,
  native_territory => "\N{U+0411}\N{U+0435}\N{U+043b}\N{U+0430}\N{U+0440}\N{U+0443}\N{U+0441}\N{U+044c}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1-\N{U+0448}\N{U+044b} \N{U+043a}\N{U+0432}.",
    "2-\N{U+0433}\N{U+0456} \N{U+043a}\N{U+0432}.",
    "3-\N{U+0446}\N{U+0456} \N{U+043a}\N{U+0432}.",
    "4-\N{U+0442}\N{U+044b} \N{U+043a}\N{U+0432}.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-\N{U+0448}\N{U+044b} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "2-\N{U+0433}\N{U+0456} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "3-\N{U+0446}\N{U+0456} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "4-\N{U+0442}\N{U+044b} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
  ],
  quarter_stand_alone_abbreviated => [
    "1-\N{U+0448}\N{U+044b} \N{U+043a}\N{U+0432}.",
    "2-\N{U+0433}\N{U+0456} \N{U+043a}\N{U+0432}.",
    "3-\N{U+0446}\N{U+0456} \N{U+043a}\N{U+0432}.",
    "4-\N{U+0442}\N{U+044b} \N{U+043a}\N{U+0432}.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-\N{U+0448}\N{U+044b} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "2-\N{U+0433}\N{U+0456} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "3-\N{U+0446}\N{U+0456} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
    "4-\N{U+0442}\N{U+044b} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
  ],
  script => undef,
  territory => "Belarus",
  time_format_full => "HH:mm:ss, zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}
